<?xml version="1.0"?>
<xsl:stylesheet
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:maki="http://maki.sourceforge.net/maki"
version="1.0">
<xsl:output method="html" />

<maki:include href="common.xsl" keepRoot="no"/>
 
<xsl:template match="/doc">
	<html>
	<head><title>Diary Demo</title></head>
	<body bgcolor="white" text="black">
		<xsl:apply-templates select="entry" />
	</body>
	</html>
</xsl:template>

<xsl:template match="entry">
	<xsl:choose>
		<xsl:when test="/doc/task='preview'">
			<xsl:if test="/doc/errors/*">
			<p>
			<font color="red">
			<b>There are errors which must be corrected before you can save.</b>
			</font>
			</p>
			</xsl:if>
			<xsl:call-template name="Entry">
				<xsl:with-param name="entry" select="."/>
			</xsl:call-template>
			<form method="post">
				<input type="hidden" name="redirect" value="{/doc/redirect}"/>
				<input type="hidden" name="id" value="{/doc/id}"/>
				<input type="hidden" name="year" value="{date/@year}"/>
				<input type="hidden" name="month" value="{date/@month}"/>
				<input type="hidden" name="day" value="{date/@day}"/>
				<input type="hidden" name="body" value="{body}"/>
				<input type="hidden" name="format" value="{format}"/>
				<input type="hidden" name="headline" value="{headline}"/>
				<input type="submit" name="task" value="edit"/>
				<xsl:if test="not(/doc/errors/*)">
					<input type="submit" name="task" value="save"/>
				</xsl:if>
			</form>
		</xsl:when>
		<xsl:otherwise>
			<form method="post">
				<input type="hidden" name="redirect" value="{/doc/redirect}"/>
				<input type="hidden" name="id" value="{/doc/id}"/>
				<table>
					<tr>
					<td valign="top" bgcolor="#aaaaaa">Date:</td>
					<td valign="top" bgcolor="#eeeeee">
						<input type="text" name="month" size="2" maxlength="2" value="{date/@month}"/>/<input type="text" name="day" size="2" maxlength="2" value="{date/@day}"/>/<input type="text" name="year" size="4" maxlength="4" value="{date/@year}"/> (mm/dd/yyyy)
						<xsl:if test="/doc/errors/date">
							[<font color="red">
								<xsl:value-of select="/doc/errors/date"/>
							</font>]
						</xsl:if>
					</td>
					</tr>
					<tr>
					<td valign="top" bgcolor="#aaaaaa">Headline:</td>
					<td valign="top" bgcolor="#eeeeee">
						<input type="text" name="headline" value="{headline}" size="60"/>
						<xsl:if test="/doc/errors/headline">
							[<font color="red">
								<xsl:value-of select="/doc/errors/headline"/>
							</font>]
						</xsl:if>
					</td>
					</tr>
					<tr>
					<td valign="top" bgcolor="#aaaaaa">Body format:</td>
					<td valign="top" bgcolor="#eeeeee">
						<select name="format">
							<option>
								<xsl:if test="format = 'text'"><xsl:attribute name="selected"/></xsl:if>
								text
							</option>
							<option>
								<xsl:if test="format = 'xhtml'"><xsl:attribute name="selected"/></xsl:if>
								xhtml
							</option>
						</select>
						<xsl:if test="/doc/errors/format">
							[<font color="red">
								<xsl:value-of select="/doc/errors/format"/>
							</font>]
						</xsl:if>
					</td>
					</tr>
					<tr>
					<td valign="top" bgcolor="#aaaaaa">Body:</td>
					<td valign="top" bgcolor="#eeeeee">
						<xsl:if test="/doc/errors/body">
							[<font color="red">
								<xsl:value-of select="/doc/errors/body"/>
							</font>]<br/>
						</xsl:if>
						<textarea name="body" cols="60" rows="10" wrap="virtual"><xsl:value-of select="body"/></textarea>
					</td>
					</tr>
					<tr>
					<td colspan="2" valign="top" bgcolor="#aaaaaa" align="center">
					<input type="submit" name="task" value="preview"/>
					<input type="submit" name="task" value="start over" onClick="return confirm('Are you sure?')"/>
					</td>
					</tr>
				</table>
			</form>
			<i>Usage Notes:</i>
			<ul>
			<li>There can be only one diary entry for each date.  Saving with a date for which another entry already exists will overwrite the old entry.</li>
			<li>The headline is optional.</li>
			<li>The body format option determines whether or not the body text may contain xhtml markup.  If set to "text", the body is treated as plain text and blank lines may be used to separate paragraphs.  If set to "xhtml", you may embed any markup you like, so long as it's well-formed xml.</li>
			</ul>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
