import spb.XmlUtil
import time

class DiaryEntry:

	def __init__(self):
		self.date = time.localtime()[0:3]
		self.headline = ""
		self.body = ""
		self.format = "text"

	def getId(self):
		try:
			return "%04d-%02d-%02d" % (int(self.date[0]), int(self.date[1]), int(self.date[2]))
		except:
			return ""

	def toSaxEvents(self, handler):
		handler.startElement("id", {})
		handler.characters(self.getId())
		handler.endElement("id")
		attrs = {}
		attrs["year"] = str(self.date[0])
		attrs["month"] = str(self.date[1])
		attrs["day"] = str(self.date[2])
		handler.startElement("date", attrs)
		handler.endElement("date")
		handler.startElement("headline", {})
		handler.characters(self.headline)
		handler.endElement("headline")
		handler.startElement("format", {})
		handler.characters(self.format)
		handler.endElement("format")
		handler.startElement("body", {})
		handler.characters(self.body)
		handler.endElement("body")
		handler.startElement("body_formatted", {})
		style = "p"
		if(self.format == 'xhtml'): style = "xhtml"
		spb.XmlUtil.XmlableText(self.body, style).toSaxEvents(handler)
		handler.endElement("body_formatted")

	def setDate(self, year, month, day):
		self.date = []
		for item in (year, month, day):
			if(item == None): item = ""
			self.date.append(str(item))

	def validate(self):
		"""returns a dict of error messages keyed by attribute name"""
		errors = {}
		if(not self.body): errors["body"] = "Required"

		if(not self.format):
			errors["format"] = "Required"
		elif(self.format not in ("text", "xhtml")):
			errors["format"] = "Invalid value"

		# see if the date is valid by trying to roundtrip it
		baddate = 1
		try:
			timelist = list(time.localtime())
			timelist[0] = int(self.date[0])
			timelist[1] = int(self.date[1])
			timelist[2] = int(self.date[2])
			testlist = time.gmtime(time.mktime(timelist))
			if(testlist[0] == timelist[0]
			and testlist[1] == timelist[1]
			and testlist[2] == timelist[2]):
				baddate = 0
		except:
			pass
		if(baddate): errors["date"] = "Invalid date"

		return errors


